/*
 *  K4Guitune - Simple chromatic tuner for KDE4.
 *  Copyright (C) 2009-2010  William Spinelli <wylliam@tiscali.it>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "k4guitune.h"

#include "k4guituneview.h"
#include "preferences.h"
#include "settings.h"

#include <KAction>
#include <KActionCollection>
#include <KStandardAction>
#include <KStatusBar>


K4Guitune::K4Guitune( ) : KXmlGuiWindow( ),
	m_view( new K4GuituneView( ) )
{
	setCentralWidget( m_view );
	setupActions( );
	statusBar( )->show( );
	setupGUI( );
}


K4Guitune::~K4Guitune( )
{
}


void K4Guitune::setupActions( )
{
	KStandardAction::quit( qApp, SLOT(closeAllWindows()), actionCollection() );
	KStandardAction::preferences( this, SLOT(optionsPreferences()), actionCollection() );
}


void K4Guitune::optionsPreferences( )
{
	if ( KConfigDialog::showDialog( "settings" ) )
		return;

	Preferences *preferences = new Preferences( this, "settings", Settings::self( ) );
	
	connect( preferences, SIGNAL(settingsChanged(const QString&)),
		m_view, SLOT(settingsChanged()) );
		
	preferences->setAttribute( Qt::WA_DeleteOnClose );
	preferences->show( );
}

#include "k4guitune.moc"
