/*
 *  K4Guitune - Simple chromatic tuner for KDE4.
 *  Copyright (C) 2009-2010  William Spinelli <wylliam@tiscali.it>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __K4GUITUNEVIEW_H_
#define __K4GUITUNEVIEW_H_

#include <QtGui/QWidget>

#include "ui_k4guituneview_base.h"

class QTimer;
class AudioProcessor;


/**
 * This is the main view class for k4guitune.  Most of the non-menu,
 * non-toolbar, and non-statusbar (e.g., non frame) GUI code should go
 * here.
 *
 * @short Main view.
 */

class K4GuituneView : public QWidget, public Ui::k4guituneview_base
{
	Q_OBJECT

public:
	/*!	@brief Default constructor.
	 */
	K4GuituneView( );

	/*!	@brief Default destructor.
	 */
	virtual ~K4GuituneView();

	
public slots:
	/*!	@brief Change the application settings.
	 */
	void settingsChanged( );
	
	/*!	@brief Notify a critical error in the application.
	 *	@param[in] error The error text to display.
	 */
	void showErrorMessage( const QString &error );


signals:
	/*!	@brief Change the content of the statusbar.
	 *	@param[in] text The next text to display in the status bar.
	 */
	void signalChangeStatusbar( const QString& text );

	/*! @brief Change the content of the caption.
	 *	@param[in] text The next caption to display.
	 */
	void signalChangeCaption( const QString& text );


private slots:
	/*!	@brief Refresh the audio graph and estimate the pitch with the latest audio samples.
	 */
	void refreshGui( );


private:
	Ui::k4guituneview_base	ui_k4guituneview_base;			//!< @brief Main view class of the application.
	AudioProcessor			*m_audioProcessor;				//!< @brief The input audio device.
	QTimer					*m_refreshTimer;				//!< @brief Timer to trigger the graph update.
};

#endif // __K4GUITUNEVIEW_H_
