/*
 *  K4Guitune - Simple chromatic tuner for KDE4.
 *  Copyright (C) 2009-2010  William Spinelli <wylliam@tiscali.it>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
\mainpage
\htmlonly
<div style="text-align:justify">
<h3>About K4Guitune 1.1.0</h3>
<p style="font-size: 13px;">K4Guitune is a program to tune a musical instrument
using your computer and its microphone or line-in input.  The pitch detection
algorithm is based on finding the first peak in the
<a href="http://en.wikipedia.org/wiki/Autocorrelation">autocorrelation</a> of
the input signal.</p>

<p style="font-size: 13px;">K4Guitune offers two systems of
<a href="http://en.wikipedia.org/wiki/Musical_tuning">musical tuning</a> (equal
temperament and just intonation), three
<a href="http://en.wikipedia.org/wiki/Pitch_%28music%29">reference pitches</a>
(normal, French and scientific) and three sets of
<a href="http://en.wikipedia.org/wiki/Note">note names</a> (English, German and
Italian).</p>

<p style="font-size: 13px;">It's a port to KDE4 of
<a href="http://home.planet.nl/~lamer024/k3guitune.html">K3Guitune</a>.</p>


<h3>Compilation from source</h3>

<p style="font-size: 13px;">The compilation from source requires the following
libraries:
<ul>
<li><a href="http://www.kde.org">KDE</a> &gt;= 4.2.0</li>
<li><a href="http://www.fftw.org">FFTW</a> &gt;= 3.1.0</li>
<li><a href="http://www.cmake.org">CMake</a> &gt;= 2.4.5</li>
</ul></p>

<p style="font-size: 13px;">Checkout the latest stable release from the SVN
repository and then start the CMake-based build process</p>
<pre style="font-size: 13px; background: #f7f7f7; border: 1px solid #d7d7d7;
margin: 1em 1.75em; padding: .25em; overflow: auto;">$ svn co svn://svn.gna.org/svn/qpitch/branches/k4guitune k4guitune
$ mkdir build &amp;&amp; cd build
$ cmake ..
$ make
$ sudo make install
$ k4guitune</pre>
</div>

<h3>Authors</h3>
<p style="font-size:13px;">Copyright &copy; 2009-2010 - William Spinelli
&lt;<a href="mailto:wylliam@tiscali.it?subject=K4Guitune">wylliam@tiscali.it</a>&gt;</p>
\endhtmlonly
*/

#include "k4guitune.h"

#include <KApplication>
#include <KAboutData>
#include <KCmdLineArgs>

#include <KDE/KLocale>


static const char description[] =
	I18N_NOOP( "Simple chromatic tuner for KDE4" );

static const char version[] = "1.1.1";


int main( int argc, char **argv )
{
	KAboutData about(
		"k4guitune",
		0,
		ki18n( "K4Guitune" ),
		version,
		ki18n( description ),
		KAboutData::License_GPL_V3,
		ki18n( "(C) 2009-2010, William Spinelli" ),
		ki18n( "K4Guitune is a program to tune a musical instrument using your computer \
			and its microphone or line-in input." ),
		"http://wspinell.altervista.org/k4guitune",
		"wylliam@tiscali.it"
    );

	about.addAuthor(
		ki18n( "William Spinelli" ),
		ki18n( "Ported K3Guitune to KDE4 under the name K4Guitune." ),
		"wylliam@tiscali.it"
	);

	about.addAuthor(
		ki18n( "Reinier Lamers" ),
		ki18n( "Ported K2Guitune to KDE3 under the name K3Guitune." ),
		"tux_rocker@planet.nl"
	);

	about.addAuthor(
		ki18n( "Florian Berger" ),
		ki18n( "Author of K2Guitune." ),
		"harpin_floh@yahoo.de"
	);

	KCmdLineArgs::init( argc, argv, &about );

	KApplication app;
	if ( app.isSessionRestored( ) ) {
		RESTORE( K4Guitune );
	} else {
		K4Guitune *k4guitune = new K4Guitune( );
		k4guitune->show();
	}

	return app.exec( );
}
